@@ -369,11 +369,31 @@ struct mod_chxj_config {
 #define CONVRULE_ENGINE_ON_BIT        (0x00000001)
 #define CONVRULE_ENGINE_OFF_BIT       (0x00000002)
 #define CONVRULE_COOKIE_ON_BIT        (0x00000004)
+#define CONVRULE_Z2H_ON_BIT           (0x00000008)
+#define CONVRULE_Z2H_OFF_BIT          (0x00000010)
+#define CONVRULE_Z2H_ALPHA_ON_BIT     (0x00000020)
+#define CONVRULE_Z2H_ALPHA_OFF_BIT    (0x00000040)
+#define CONVRULE_Z2H_NUM_ON_BIT       (0x00000080)
+#define CONVRULE_Z2H_NUM_OFF_BIT      (0x00000100)
+#define CONVRULE_QS_CONV_ON           (0x00000200)
+#define CONVRULE_QS_CONV_OFF          (0x00000400)
 
 #define CONVRULE_ENGINE_ON_CMD        "EngineOn"
 #define CONVRULE_ENGINE_OFF_CMD       "EngineOff"
 #define CONVRULE_COOKIE_ON_CMD        "CookieOn"
 #define CONVRULE_COOKIE_OFF_CMD       "CookieOff"
+#define CONVRULE_Z2H_ON_CMD           "Z2hOn"
+#define CONVRULE_Z2H_OFF_CMD          "Z2hOff"
+#define CONVRULE_Z2H_ALPHA_ON_CMD     "Z2hAlphaOn"
+#define CONVRULE_Z2H_ALPHA_OFF_CMD    "Z2hAlphaOff"
+#define CONVRULE_Z2H_NUM_ON_CMD       "Z2hNumOn"
+#define CONVRULE_Z2H_NUM_OFF_CMD      "Z2hNumOff"
+#define CONVRULE_Z2H_ALL_ON_CMD       "Z2hAllOn"
+#define CONVRULE_Z2H_ALL_OFF_CMD      "Z2hAllOff"
+#define CONVRULE_Z2H_ALL_ON_CMD       "Z2hAllOn"
+#define CONVRULE_Z2H_ALL_OFF_CMD      "Z2hAllOff"
+#define CONVRULE_QS_CONV_ON_CMD       "QSConvOn"
+#define CONVRULE_QS_CONV_OFF_CMD      "QSConvOff"
 
 
 #define CONVRULE_FLAG_NOTMATCH        (0x00000001)
