@@ -1499,8 +1499,8 @@ s_chtml20_start_form_tag(void *pdoc, Node *node)
     char *new_query_string = NULL;
     q = strchr(attr_action, '?');
     if (q) {
-      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_action, 0, post_flag, &new_query_string, CHXJ_TRUE);
-      if (new_hidden_tag) {
+      new_hidden_tag = chxj_form_action_to_hidden_tag(r, doc->pool, attr_action, 0, post_flag, &new_query_string, CHXJ_TRUE, CHXJ_FALSE);
+      if (new_hidden_tag || new_query_string) {
         *q = 0;
       }
     }
@@ -2354,7 +2354,7 @@ s_chtml20_start_option_tag(void *pdoc, Node *child)
     }
   }
 
-  if (value && *value) {
+  if (value) {
     W_L(" value=\"");
     W_V(value);
     W_L("\"");
